<?php
/**
 * 2007-2021 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2021 PrestaShop SA
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */
 
if (!defined('_PS_VERSION_')) {
    exit;
}

require_once(dirname(__FILE__) . '/classes/CombinationValue.php');
require_once(dirname(__FILE__) . '/classes/ConfigHistory.php');
require_once(dirname(__FILE__) . '/classes/CarrierMatches.php');
require_once(dirname(__FILE__) . '/classes/PaymentMatches.php');



class ns_caisseEnregistreusepro extends Module
{
    protected $config_form = false;
    
    public function __construct()
    {
        $this->name = 'ns_caisseEnregistreusepro';
        $this->tab = 'billing_invoicing';
        $this->version = '1.0.1';
        $this->author = 'GwadaRepas';
        $this->need_instance = 1;
        
        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;
        
        parent::__construct();
        
        $this->displayName = $this->l('Caisse Enregistreuse POS');
        $this->description = $this->l('Centralise les ventes dans caisse enregistreuse gratuite');
		/*Centralisez vos ventes dans un logiciel de caisse. */
        
        $this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_);
    }
    
    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        /*
		Configuration::updateValue('CAISSEENREGISTREUSE_LIVE_MODE', true);
        Configuration::updateValue('CAISSEENREGISTREUSE_DEBUG_MODE', true); 
		
		*/
		
		$sql = array();		
		
		
		
		$sql[] = 'CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'ns_caisseconfig` (
                  `id_ns_caisseconfig` int(10) unsigned NOT NULL AUTO_INCREMENT,
				  `id_shop` INT( 11 ) UNSIGNED NOT NULL,
                  `combination_id` INT( 11 ) UNSIGNED NOT NULL,				  				  
                  `combination_value` TEXT ,
				  `encoded_value` TEXT ,
                  PRIMARY KEY (`id_ns_caisseconfig`)
                ) ENGINE='._MYSQL_ENGINE_.' DEFAULT CHARSET=utf8';
				
		
        $sql[] = 'CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'ns_caisse_orders` (
                  `id_ns_caisse_orders` int(10) unsigned NOT NULL AUTO_INCREMENT,
				  `id_shop` INT( 11 ) UNSIGNED NOT NULL,
                  `id_order` INT( 11 ) UNSIGNED NOT NULL,				  				  
                  `url_value` TEXT ,
				  `response` INT( 11 ) UNSIGNED NOT NULL,
                  `server_message` TEXT ,				  
                  PRIMARY KEY (`id_ns_caisse_orders`),
				  UNIQUE  `CAISSE_ORDER_UNIQ` (`id_order`)
                ) ENGINE='._MYSQL_ENGINE_.' DEFAULT CHARSET=utf8';	
         

        $sql[] = 'CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'ns_transporteur` (
                  `id_ns_transporteur` int(10) unsigned NOT NULL AUTO_INCREMENT,
				  `id_shop` INT( 11 ) UNSIGNED NOT NULL,
				  `id_carrier` INT( 11 ) UNSIGNED NOT NULL,
                  `livraison_id` INT( 11 ) UNSIGNED NOT NULL,                  
                  PRIMARY KEY (`id_ns_transporteur`)
                ) ENGINE='._MYSQL_ENGINE_.' DEFAULT CHARSET=utf8';		
        				
		
		 $sql[] = 'CREATE TABLE IF NOT EXISTS `'._DB_PREFIX_.'ns_paiement` (
                  `id_ns_paiement` int(10) unsigned NOT NULL AUTO_INCREMENT,
				  `id_shop` INT( 11 ) UNSIGNED NOT NULL,
				  `id_payment` INT( 11 ) UNSIGNED NOT NULL,
                  `cash_payment_id` INT( 11 ) UNSIGNED NOT NULL,                  
                  PRIMARY KEY (`id_ns_paiement`)
                ) ENGINE='._MYSQL_ENGINE_.' DEFAULT CHARSET=utf8';	
				
				
		
        $this->logData("Install");
        return parent::install() &&
        $this->registerHook('header') &&
		$this->registerHook('DisplayPaymentTop') &&
		$this->registerHook('DisplayOrderConfirmation') &&	
		$this->registerHook('OrderConfirmation') &&
        $this->runSql($sql) &&		
        $this->registerHook('actionValidateOrder') /*&&
        $this->registerHook('actionCustomerAccountUpdate') &&
        $this->registerHook('actionCustomerAccountAdd') &&
        $this->registerHook('actionPaymentConfirmation') &&
        $this->registerHook('backOfficeHeader') &&
        $this->registerHook('displayPayment') &&
		$this->registerHook('ctionOrderHistoryAddAfter') &&
        $this->registerHook('displayPaymentReturn')*/;
    }
    
    public function uninstall()
    {
          $sql = array();
		    
			
		    $sql[] = 'DROP TABLE IF EXISTS `'._DB_PREFIX_.'ns_caisseconfig`';			
		    $sql[] = 'DROP TABLE IF EXISTS `'._DB_PREFIX_.'ns_caisse_orders`';
			$sql[] = 'DROP TABLE IF EXISTS `'._DB_PREFIX_.'ns_transporteur`';
			$sql[] = 'DROP TABLE IF EXISTS `'._DB_PREFIX_.'ns_paiement`';
            	
		    
		 
		 /*
		Configuration::deleteByName('CAISSEENREGISTREUSE_LIVE_MODE');
        Configuration::deleteByName('CAISSEENREGISTREUSE_DEBUG_MODE');
        Configuration::deleteByName('CAISSEENREGISTREUSE_ACCOUNT_API');
        Configuration::deleteByName('CAISSEENREGISTREUSE_ACCOUNT_SHOPID');
       */ 
	   
	    $this->runSql($sql);  
		 
        return parent::uninstall();
    }
	
	
	public function runSql($sql) {	
        foreach ($sql as $s) {
			if (!Db::getInstance()->Execute($s)){
				return FALSE;
			}
        }
        return TRUE;
    }
    
    /**
     * Load the configuration form
     */
	 
    public function getContent()
    {
        /**
         * If values have been submitted in the form, process.
         */
		 
		$output=$this->addMenu();
		
		$this->context->smarty->assign('token', Tools::getAdminTokenLite('AdminModules')); 	
		$this->context->smarty->assign('id_current_shop', $this->context->shop->id); 
		$this->context->smarty->assign('current_shop', $this->context->shop); 
       		
		
        $id_lang=Configuration::get('PS_LANG_DEFAULT');		
		$shop_list=Shop::getShops(true);
		$this->context->smarty->assign('shop_list', $shop_list); 	
		
		 
        if (((bool)Tools::isSubmit('submitCaisseEnregistreuseModule')) == true) {
            $this->postProcess();
        }
        
		if(Tools::isSubmit('viewHelp') ){
        $this->context->smarty->assign('module_dir', $this->_path);
        
        $output .= $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');
		
		}
		
		elseif(Tools::isSubmit('viewCombinations') || Tools::isSubmit('submitAddCombination') ||
		       Tools::isSubmit('updatens_caisseconfig')  || Tools::isSubmit('deletens_caisseconfig')){
			
			
		  
		  
		  
		    if(Tools::getValue('id_ns_caisseconfig')!='' && Tools::isSubmit('deletens_caisseconfig')){
		       $id_ns_caisseconfig=(int)Tools::getValue('id_ns_caisseconfig');
			   $sampleObj=new CombinationValue($id_ns_caisseconfig); 
               $sampleObj->delete();	
               $output .=$this->displayConfirmation($this->l('Item  Removed'));			   
			 }
			
		     if(Tools::getValue('id_ns_caisseconfig')!='' && Tools::isSubmit('updatens_caisseconfig')){
		  	 $id_ns_caisseconfig=(int)Tools::getValue('id_ns_caisseconfig');
			 $sampleObj=new CombinationValue($id_ns_caisseconfig);  
             $this->context->smarty->assign('sampleObj', $sampleObj);			 
		     }
			 
			 if(Tools::isSubmit('submitAddCombination')){
			 
			 $output .=$this->addCombination();
		     }
             
		
        $output .= $this->context->smarty->fetch($this->local_path.'views/templates/admin/config_combinations.tpl');		
		$output .= $this->renderItemsComb();
		

        /* $this->displayError($this->l('Invalid Configuration value')); */		
		
		}
		
		
		
		elseif(Tools::isSubmit('viewHistory') || Tools::isSubmit('deletens_caisse_orders')){
		$id_shop=$this->context->shop->id;	
		$all_order_histories=ConfigHistory::getHistories($id_shop);	
        $this->context->smarty->assign('all_order_histories', $all_order_histories);  

        if(Tools::isSubmit('deletens_caisse_orders') && Tools::getValue('id_ns_caisse_orders')!=''){
			
		   $id_ns_caisse_orders=(int)Tools::getValue('id_ns_caisse_orders');
		   $ConfigHistory=new ConfigHistory($id_ns_caisse_orders);
		   $ConfigHistory->delete();
		
           $output .=$this->displayConfirmation($this->l('Item  Removed'));	  
		  
		}
		
        $output .= $this->context->smarty->fetch($this->local_path.'views/templates/admin/config_history.tpl');	
		
		}
		
		elseif(Tools::isSubmit('viewOptions') ||  Tools::isSubmit('submitConfigOptions')){          
          if(Tools::isSubmit('submitConfigOptions')){			 
			  $output .=$this->updateOptionValues();			  
		  }		 
         $output .= $this->context->smarty->fetch($this->local_path.'views/templates/admin/config_options.tpl');	
        		
		}
		
		
		elseif(Tools::isSubmit('viewCarrierMatches') ||  Tools::isSubmit('submitCarrierMatches') || Tools::isSubmit('deletens_transporteur')){	
		$this->context->smarty->assign('carrier_list', Carrier::getCarriers($id_lang, true));
		$this->context->smarty->assign('carrier_matches_list', CarrierMatches::getMatches($this->context->shop->id));		
		 
		if(Tools::isSubmit('submitCarrierMatches')){		
             $id_carrier=Tools::getValue('id_carrier');	
			 $livraison_id=Tools::getValue('livraison_id');	
			 $output .=$this->addNewMatches($id_carrier, $livraison_id);			  
		  }		 
		  
		  if(Tools::isSubmit('deletens_transporteur') && Tools::getValue('id_ns_transporteur')){
			$id_ns_transporteur=Tools::getValue('id_ns_transporteur');	
            $TransPorteur=new CarrierMatches($id_ns_transporteur);	
            $TransPorteur->delete();           			
			$output .=$this->displayConfirmation($this->l('Item  Removed'));	  
			  
		  }
		  
         $output .= $this->context->smarty->fetch($this->local_path.'views/templates/admin/config_carriers.tpl');
		
		
		}
		
		elseif(Tools::isSubmit('viewPaymentMatches') ||  Tools::isSubmit('submitPaymentMatches') || Tools::isSubmit('deletens_paiement')){		
		$this->context->smarty->assign('payment_methods', $this->getPaymentMethods());		
		$this->context->smarty->assign('payment_matches_list', PaymentMatches::getMatches($this->context->shop->id));      		
	   
	   if(Tools::isSubmit('deletens_paiement') && Tools::getValue('id_ns_paiement')){
			$id_ns_paiement=Tools::getValue('id_ns_paiement');	
            $PaymentMatches=new PaymentMatches($id_ns_paiement);	
            $PaymentMatches->delete();           			
			$output .=$this->displayConfirmation($this->l('Item  Removed'));	  
			  
		  }
	   
		 
		if(Tools::isSubmit('submitPaymentMatches')){		
             $id_payment=Tools::getValue('id_payment');	
			 $cash_payment_id=Tools::getValue('cash_payment_id');	
			 $output .=$this->addNewPaymentMatches($id_payment,$cash_payment_id);			  
		  }		 
         $output .= $this->context->smarty->fetch($this->local_path.'views/templates/admin/config_payments.tpl');
		
		
		}		
		
		elseif(Tools::isSubmit('viewWhatsAppSettings') || Tools::isSubmit('submitAppSettings')){ 

          if(Tools::isSubmit('submitAppSettings')){			 
			  $output .=$this->updateAppSettings();			  
		  }				
        
          $output .= $this->context->smarty->fetch($this->local_path.'views/templates/admin/config_whatsapp.tpl');		
		}			
		
		
		

        elseif(Tools::isSubmit('viewCaisse') ){             
        $output .= $this->displayCaisse();		
		}			
		
		
		else{
			 
			 $output.=$this->renderForm();
		}
        
        return $output;
    }
	
	
	public function addMenu(){

	$button= '<div class="panel">';
	$button .= '<a href="'.$this->context->link->getAdminLink('AdminModules', false).'&viewHome&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'">
	<button class="btn btn-default"><i class="icon-wrench"></i> '.$this->l('Home').'</button>
	</a>';
	
	$button .= '<a href="'.$this->context->link->getAdminLink('AdminModules', false).'&viewCombinations&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'">
	<button class="btn btn-default">'.$this->l('Config. Declinaisons').'</button>
	</a>';	
	
	$button .= '<a href="'.$this->context->link->getAdminLink('AdminModules', false).'&viewHistory&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'">
	<button class="btn btn-default"><i class="icon-AdminCatalog"></i> '.$this->l('Order History').'</button>
	</a>';	
	
	$button .= '<a href="'.$this->context->link->getAdminLink('AdminModules', false).'&viewOptions&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'">
	<button class="btn btn-default"><i class="icon-cogs"></i> '.$this->l('Options').'</button>
	</a>';	
	
	$button .= '<a href="'.$this->context->link->getAdminLink('AdminModules', false).'&viewCarrierMatches&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'">
	<button class="btn btn-default"><i class="icon-cogs"></i> '.$this->l(' Carriers ').'</button>
	</a>';
    $button .= '<a href="'.$this->context->link->getAdminLink('AdminModules', false).'&viewPaymentMatches&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'">
	<button class="btn btn-default"><i class="icon-cogs"></i> '.$this->l(' Payments ').'</button>
	</a>';

    /*$button .= '<a href="'.$this->context->link->getAdminLink('AdminModules', false).'&viewWhatsAppSettings&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'">
	<button class="btn btn-default"><i class="icon-cogs"></i> '.$this->l(' WhatsApp Settings ').'</button>
	</a>'; */		
	
	$button .= '<a href="'.$this->context->link->getAdminLink('AdminModules', false).'&viewCaisse&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'">
	<button class="btn btn-default">'.$this->l(' Caisse').'</button>
	</a>';	
	
	
	$button .= '<a href="'.$this->context->link->getAdminLink('AdminModules', false).'&viewHelp&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules').'">
	<button class="btn btn-default">'.$this->l('Aide?').'</button>
	</a>';
	
	
	
	$button .='</div>';



	return $button;

	}   
	
	
	public function displayCaisse(){		
		
		$shopID=Configuration::get('CAISSEENREGISTREUSE_ACCOUNT_SHOPID',null,null, $this->context->shop->id);
		$accountKEYAPI=Configuration::get('CAISSEENREGISTREUSE_ACCOUNT_API',null,null, $this->context->shop->id);
		
		$urlWS = "https://caisse.enregistreuse.fr/workers/webapp.php?idboutique=".$shopID."&key=".$accountKEYAPI;
		$urlcaisse = "https://caisse.enregistreuse.fr/";
        $html= '
		<br/>
		<fieldset>
			<legend><img src="'.$this->_path.'img/more.png" alt="" title="" /> '.$this->l('Details de la Caisse').'</legend>	
			<iframe src="'.$urlcaisse.'" width="100%" height="800px;" border="0" style="border:none;"></iframe>
			</fieldset>';
			
	     return $html;	
		
  
      }
	  
	  
	  public  function addCombination(){
		  
		  $message='';
		  
	  $is_duplicated=CombinationValue::verifyByNUmber((int)Tools::getValue('combination_id'));
                    
           	  /*  && empty($is_duplicated)*/
		  
      if(Tools::isSubmit('submitAddCombination') && Tools::getValue('combination_value')!='' &&  Tools::getValue('combination_id')!='' ){	  
	 	       
        $id_ns_caisseconfig=Tools::getValue('id_ns_caisseconfig'); 
		
        $sampleObj = CombinationValue::loadByIdCombination($id_ns_caisseconfig);
        $encoded_value=Tools::getValue('combination_value'); 		
        $sampleObj->encoded_value =rawurlencode(strtoupper(str_replace(' ','', $encoded_value))); 
        $sampleObj->combination_value =Tools::getValue('combination_value'); 		
		
        $sampleObj->combination_id = Tools::getValue('combination_id');  
		$sampleObj->id_shop =(int)Tools::getValue('id_shop');  
        
        if(!empty($sampleObj) && isset($sampleObj->id) && Tools::getValue('id_ns_caisseconfig')!=''){
            $sampleObj->update();
			$message=$this->displayConfirmation($this->l('Item updated'));
        } else {            			
            $sampleObj->add();
			
			$message=$this->displayConfirmation($this->l('Item  added'));
		
        } 		  
		  
	  
	  
	  }
	      return $message;
		  
	  }
	  
	  
	    	public function renderItemsComb()
	{
		$fields_list = array(
		
		   'id_ns_caisseconfig' => array(
				'title' => $this->l('ID'),
				'search' => false,
			),
			'id_shop' => array(
				'title' => $this->l('ID SHOP'),
				'search' => false,
			),	
         			
			'combination_value' => array(
				'title' => $this->l('Combination'),
				'search' => false,
			),
			
			'encoded_value' => array(
				'title' => $this->l('Encoded'),
				'search' => false,
			),
			
			
            'combination_id' => array(
				'title' => $this->l('VALUE'),
				'search' => false,
			)			
					
			
		);
		
		

		if (!Configuration::get('PS_MULTISHOP_FEATURE_ACTIVE'))
			unset($fields_list['shop_name']);
		$helper_list = New HelperList();
		$helper_list->module = $this;
		$helper_list->title = $this->l('Combination: Items');
		$helper_list->shopLinkType = '';
		$helper_list->no_link = true;
		$helper_list->show_toolbar = true;
		$helper_list->simple_header = false;
		$helper_list->identifier = 'id_ns_caisseconfig';
		$helper_list->table = 'ns_caisseconfig';
		$helper_list->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&viewCombinations&configure='.$this->name;
		$helper_list->token = Tools::getAdminTokenLite('AdminModules');
		$helper_list->actions = array('edit','delete');
		$helper_list->bulk_actions = array(
			'select' => array(
				'text' => $this->l('Change order status'),
				'icon' => 'icon-refresh',				
			)
		); 		

		// This is needed for displayEnableLink to avoid code duplication
		$this->_helperlist = $helper_list;

		/* Retrieve list data */
		$id_shop=(int)$this->context->shop->id;
	    $orders=CombinationValue::getItems($id_shop);		
		$helper_list->listTotal = count($orders);

		/* Paginate the result */
		$page = ($page = Tools::getValue('submitFilter'.$helper_list->table)) ? $page : 1;
		$pagination = ($pagination = Tools::getValue($helper_list->table.'_pagination')) ? $pagination : 50;
		$orders = $this->paginateOrderProducts($orders, $page, $pagination);

		return $helper_list->generateList($orders, $fields_list);
		
	}
  
   
    public function paginateOrderProducts($orders, $page = 1, $pagination = 50)
	{
		if(count($orders) > $pagination)
			$orders= array_slice($orders, $pagination * ($page - 1), $pagination);

		return $orders;
	}  
  
	  
    
    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();
        
        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);
        
        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitCaisseEnregistreuseModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
        .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        
        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );
        
        return $helper->generateForm(array($this->getConfigForm()));
    }
    
    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {
        return array(
            'form' => array(
                'legend' => array(
                    'title' => $this->l('Settings'),
                    'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'col' => 3,
                        'type' => 'text',
                        //'prefix' => '<i class="icon icon-envelope"></i>',
                        'desc' => $this->l('Enter your cash register API key'),
                        'name' => 'CAISSEENREGISTREUSE_ACCOUNT_API',
                        'label' => $this->l('API key'),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'text',
                        //'prefix' => '<i class="icon icon-envelope"></i>',
                        'desc' => $this->l('Enter your cash register shop ID'),
                        'name' => 'CAISSEENREGISTREUSE_ACCOUNT_SHOPID',
                        'label' => 'Shop ID',
                    ),
                    /*array(
                     'type' => 'password',
                     'name' => 'CAISSEENREGISTREUSE_ACCOUNT_PASSWORD',
                     'label' => $this->l('Password'),
                     ),*/
                ),
                'submit' => array(
                    'title' => $this->l('Save'),
                ),
            ),
        );
    }
    
    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        return array(
            'CAISSEENREGISTREUSE_ACCOUNT_API' => Configuration::get('CAISSEENREGISTREUSE_ACCOUNT_API', 'xxxxxxxx',null,null, $this->context->shop->id),
            'CAISSEENREGISTREUSE_ACCOUNT_SHOPID' => Configuration::get('CAISSEENREGISTREUSE_ACCOUNT_SHOPID', null,null, $this->context->shop->id),
        );
    }
    
    /**
     * Save form data.
     */
    protected function logData($txt)
    {
        $f = fopen($this->local_path.'logBackground.txt',"a+");
        fwrite($f,date("m/d/Y H:i ").$txt."\r\n");
        fclose($f);
        //file_put_contents($this->local_path.'hookActionUpdateQuantity.txt', $data , LOCK_EX);
    }
    
    /**
     * Save form data.
     */
    protected function postProcess()
    {
        $form_values = $this->getConfigFormValues();
        foreach (array_keys($form_values) as $key) {
            Configuration::updateValue($key, Tools::getValue($key),false,null, $this->context->shop->id);
        }
    }
    
    /**
     * Add the CSS & JavaScript files you want to be loaded in the BO.
     */
    public function hookBackOfficeHeader()
    {
        if (Tools::getValue('module_name') == $this->name && false) {
            $this->context->controller->addJS($this->_path.'views/js/back.js');
            $this->context->controller->addCSS($this->_path.'views/css/back.css');
        }
    }
    
    /**
     * Add the CSS & JavaScript files you want to be added on the FO.
     */
	 
    public function hookHeader()
    {
        $this->context->controller->addJS($this->_path.'/views/js/front.js');
        $this->context->controller->addCSS($this->_path.'/views/css/front.css');
    }
    //actionUpdateQuantity actionCustomerAccountUpdate actionCustomerAccountAdd actionProductSave actionPaymentConfirmation
    public function hookActionCustomerAccountUpdate($params)
    {
        $data = print_r($params,true);
        //$this->logData('hookActionCustomerAccountUpdate '. $data);
        
    }
    public function hookActionUpdateQuantity($params)
    {
        $data = print_r($params,true);
        //$this->logData('hookActionUpdateQuantity '. $data);
    }
    public function hookActionCustomerAccountAdd($params)
    {
        $data = print_r($params,true);
        //$this->logData('hookActionCustomerAccountAdd '. $data);
    }
    public function hookActionPaymentConfirmation($params)
    {
        $data = print_r($params,true);
        //$this->logData('actionPaymentConfirmation '. $data);
    }
	public function hookActionOrderHistoryAddAfter($params)
	{
		$data = print_r($params,true);
        //$this->logData('actionPaymentConfirmation '. $data);
	}
	
	
    public function hookActionValidateOrder($params)
    {
		/*  ndiaga :je  l'ai  change  de  hook*/
	   return  '';
	     
	}    
    public function hookDisplayPayment($params)
    {
        /* Place your code here. */
    }
    
	public function hookDisplayPaymentTop($params)
    {
        /* Place your code here. */
    }
    public function hookDisplayPaymentReturn()
    {
        /* Place your code here. */
    }
	
	
	
	public function  hookDisplayOrderConfirmation($params) 
   {    

	 $id_order =(int)Tools::getValue('id_order'); 	
     
     
	  
	  if(Configuration::get('SEND_ORDERS',null, null, $this->context->shop->id)==1){
		  
	  if(ConfigHistory::isOrderExist($id_order)==true){		  
		  return '';		  
	  }	  
	  else{	  
	  return $this->hookOrderConfirmation($params);	  
	  }	  
     } 
	 
	 
	 
	 
	 
	 
	/* echo   '<pre>'.print_r($this->getDeclinaison($params)).'</pre>';  */
	 
	 
	
	 
	    
   }  
   
   
 
 
   
    public function hookOrderConfirmation($params)
    {
         /*  start  ndiaga*/
		 
		$accountKEYAPI = Configuration::get('CAISSEENREGISTREUSE_ACCOUNT_API', null,null, $this->context->shop->id);
        $shopID = Configuration::get('CAISSEENREGISTREUSE_ACCOUNT_SHOPID', null,null, $this->context->shop->id);
        $liveMode = true;/*Tools::getValue('CAISSEENREGISTREUSE_LIVE_MODE',Configuration::get('CAISSEENREGISTREUSE_LIVE_MODE', null)); */
        $debugMode = true;/*Tools::getValue('CAISSEENREGISTREUSE_DEBUG_MODE',Configuration::get('CAISSEENREGISTREUSE_DEBUG_MODE', null)); */
        
        if (!$liveMode) {
            if ($debugMode) file_put_contents($this->local_path.'LiveModeNotEnabled.txt',serialize($accountKEYAPI), LOCK_EX);
            return;
        }
        if ($accountKEYAPI===null || $accountKEYAPI=='xxxxxxxx' || $accountKEYAPI=='') {
            if ($debugMode) $this->logData('API KEY invalid '. $accountKEYAPI);
            return;
        }
		
        /*file_put_contents($this->local_path.'hookActionValidateOrderWSConfig.txt',serialize($accountKEYAPI), LOCK_EX); */
        
        
        $id_order =(int)Tools::getValue('id_order');
		$order=new Order($id_order );
        
		/* $status = $params['orderStatus']->id; ndiaga */
	   $nka_current_state=$order->current_state;
	   $status =new OrderState((int)$nka_current_state);
	   
        $dateValeur =$this->getDateLivraison($params);        
		
        $data = print_r($params,true);
        if ($debugMode) file_put_contents($this->local_path.'hookActionValidateOrder.txt', $data, LOCK_EX);
		
		$tran3 =$this->getTransporteur($params);	
        
        $codeBarreClient = "Pr".$this->context->customer->id;
        $modePaiement = $params['order']->payment; 
		$paiement1 =$this->getPaymentMethods();	
		$id_payment=(int)Tools::getValue('id_module');
		$paiement3=PaymentMatches::getPaymentMethod($id_payment);
        
		$customer = $this->context->customer;		
		$addedItems=$this->getAddedItems($params);		
        $infosClient=$this->getInfosClient($params);	
		$message = $params['order']->gift_message;
		$messager=rawurlencode($message);

        
		 $urlWS = "https://caisse.enregistreuse.fr/workers/webapp.php?idboutique=".$shopID."&key=".$accountKEYAPI."&payment=".$paiement3;
		 $urlWS.="&dateValeur=".$dateValeur."&idUser=Prestashop".$infosClient."&deliveryMethod=".$tran3.$addedItems."&comment=".$messager;
		
        if ($debugMode) $this->logData('Fetch url : '. $urlWS);
        
        $result = file_get_contents($urlWS);
        if ($result===false) {
            $error = error_get_last();
            if ($debugMode) $this->logData('HTTP request failed. Error was : '. $error['message']);
        }
        
        $recordResult = json_decode(str_replace("'", '"', $result));
		
		$response=null;
        $server_message=null;
		
        if ($recordResult) {
            if (property_exists($recordResult,'errorMessage')) {
                if ($debugMode) $this->logData('Server returned explicit error message : '. $recordResult->errorMessage);
				$response=0; 
				$server_message='Server returned explicit error message : '. $recordResult->errorMessage;
            }
            if (property_exists($recordResult,'orderID')) {
                if ($debugMode) $this->logData('Order was successfully created : '. $recordResult->orderID);
				$response=1;
				$server_message='Order was successfully created : '. $recordResult->orderID;
            }
        }
	  
         $this->sendHistory($params,$response,$server_message,$urlWS);
		 
		 $this->sendEmail($urlWS,$server_message,$params);
		 
		 /*  end  ndiaga */
    }
	
	
	public  function sendHistory($params,$response,$server_message,$urlWS){
		
		$id_customer=(int)($this->context->customer->logged ? $this->context->customer->id: false);
		 
		 $shopID = Configuration::get('CAISSEENREGISTREUSE_ACCOUNT_SHOPID',null,null, $this->context->shop->id);
		 $accountKEYAPI = Configuration::get('CAISSEENREGISTREUSE_ACCOUNT_API',null,null, $this->context->shop->id);        
		
		$id_order =(int)Tools::getValue('id_order');
		$order=new Order($id_order );
        /* $status = $params['orderStatus']->id; ndiaga */
	    $nka_current_state=$order->current_state;
	    $status =new OrderState((int)$nka_current_state);		 
		  
		 $ConfigHistory=ConfigHistory::loadByIdOrder($id_order);		  
		 $ConfigHistory->id_order=$params['order']->id;	
	     $ConfigHistory->id_shop=$this->context->shop->id;	 
	     $ConfigHistory->url_value=$urlWS;	
	     $ConfigHistory->response=$response;
		 $ConfigHistory->server_message=$server_message;
		 
		 if(!empty($ConfigHistory) && isset($ConfigHistory->id)){
            $ConfigHistory->update();
        } else {
            $ConfigHistory->add();
        }
		 
		 
	}
	
	
	 /*   get  the  customer  details */
	 
public  function getInfosClient($params){
		
		$customer = $this->context->customer;
		$id_address_first=Address::getFirstCustomerAddressId($customer->id,true);
		$id_address_delivery=$params['order']->id_address_delivery;
		$Address=new Address($id_address_delivery);
	    
		
        $infosClient = "";
        $infosClient .= "&client[nom]=".rawurlencode($customer->lastname);
        $infosClient .= "&client[prenom]=".rawurlencode($customer->firstname);
        $infosClient .= "&client[email]=".rawurlencode($customer->email);
        $infosClient .= "&client[telephone]=".rawurlencode($Address->phone);
        $infosClient .= "&client[adresseligne1]=".rawurlencode($Address->address1);
        $infosClient .= "&client[adresseligne2]=".rawurlencode($Address->address2);
        $infosClient .= "&client[commentaireadresse]=".rawurlencode($Message->message);
        $infosClient .= "&client[codepostal]=".rawurlencode($Address->postcode);
        $infosClient .= "&client[ville]=".rawurlencode($Address->city);
        $infosClient .= "&client[pays]=".rawurlencode($Address->country);
        $infosClient .= "&client[rcs]=".rawurlencode($customer->siret);
        $infosClient .= "&client[codeBarre]=Pr".($customer->id+30000);
        $infosClient .= "&client[telephone2]=".rawurlencode($customer->phone_mobile);	
		/* Geolocation */		
		//$infosClient .= "&client[lat]=".rawurlencode($Location->delLat);
		//$infosClient .= "client[lng]=".rawurlencode($Location->delLng);
		//$infosClient .= "&client[eoloc_postcode]=".rawurlencode($customer->eoloc_postcode);
		
		
        //$infosClient .= "&client[rcs]=".rawurlencode($customer->siret);
        //$infosClient .= "&client[codeBarre]=Pr".$customer->id;
				
		return $infosClient;
		
	}
	
	
	  public  function getDeclinaison($params){
	   
	    $id_order =(int)Tools::getValue('id_order');
		$order=new Order($id_order );
		$id_cart =(int)$order->id_cart; 
	    $cart=new cart($id_cart);
	    $cart_products=$cart->getProducts();
		
	    
		$decli4='';
		
	 
	 foreach($cart_products  as $product){
		   $decli=rawurlencode($product['attributes']);	 // TODO: rawurlencode
           $liste=CombinationValue::doReplace($decli);
		$liste1 = explode("-",$liste);  // separe le texte avec tiret comme separateur		
		$nompizza = $liste1[0];		
		$decli4 =$nompizza; 		   
		  }	  

      return $decli4;	  
	  
	  
	   
   }

	
	/*   get Order Items   */
	
	public function getAddedItems($params){
		
		$id_order =(int)Tools::getValue('id_order');
		$order=new Order($id_order );
		
		$productList =$order->getProducts();
		  
        $addedItems = "";	
		
		
        foreach ($productList as $product) {			
		
		$decli =rawurlencode(strtoupper($product['product_name']));  
		$liste=CombinationValue::doReplace($decli);
		$liste1 = explode("-",$liste);  	
		$nompizza = $liste1[0];		
		$decli4 =$nompizza;
		
		
		$addedItems .= "&itemsList[]=|Pr".$product['product_id']."_".$product['product_quantity']."__".rawurlencode($product['total_wt']/$product['product_quantity'])."code".$decli4;
     
		}
	
        
        $totalDiscount = $params['order']->total_discounts;
        if ($totalDiscount) {
            $addedItems .= "&itemsList[]=-1_1_".rawurlencode("Discount")."_-".$totalDiscount;
        }
        
        
        $shippingPrice = $params['order']->total_shipping;
        if ($shippingPrice) {
            $addedItems .= "&itemsList[]=-0_1_".rawurlencode("Shipping")."_".$shippingPrice;
        }
		  
		  
		return $addedItems;  
		  
		  
	}
	
	
	 
	
	/*tranporteur*/
	public  function getTransporteur($params){
		
		
		$id_carrier = $params['order']->id_carrier;
		$carrier_matche=CarrierMatches::getDeliveryMethod($id_carrier);
		
		
		return $carrier_matche;
		
	}
	
	/*Date heure de livraison */
	public  function getDateLivraison($params){		
		
		$dat = $params['cookie']->msg;
		/*$dat1 = date_format($dat, 'Y-m-d H:i:s') */
		$d = $params['order']->delivery_date ; 
        $d1 = strtotime ( $dat ); 
		$time_difference=Configuration::get('TIME_DIFFERENCE',null, null, $this->context->shop->id);
        /*$d1 on  enleve 6H;*/		
        $dateValeur =strtotime ($params['order']->delivery_date)-($time_difference*3600);   
		$dateValeur = str_replace ( "-62169983636" ,"",$dateValeur);
		
		return $dateValeur;
		
	}
	


    public function updateOptionValues()
    {
		   $message='';
		
               if (Tools::isSubmit('submitConfigOptions')) {
			   
				Configuration::updateValue('TIME_DIFFERENCE', (int)Tools::getValue('TIME_DIFFERENCE'),false,null, $this->context->shop->id);
                Configuration::updateValue('EMAIL_ADRESS',  Tools::getValue('EMAIL_ADRESS'),false,null, $this->context->shop->id);
                Configuration::updateValue('RECEIVE_EMAIL_NOTIFICATION', (bool) Tools::getValue('RECEIVE_EMAIL_NOTIFICATION'),false,null, $this->context->shop->id);
				Configuration::updateValue('SEND_ORDERS', (bool) Tools::getValue('SEND_ORDERS'),false,null, $this->context->shop->id);
				
				/*   User  Codes */				
				
				Configuration::updateValue('USER_PrestaShop_CODE', (int)Tools::getValue('USER_PrestaShop_CODE'),false,null, $this->context->shop->id);
				Configuration::updateValue('USER_Lucien_CODE', (int)Tools::getValue('USER_Lucien_CODE'),false,null, $this->context->shop->id);
				
				
				
				
				
				
			$message=$this->displayConfirmation($this->l('Options  Saved  Successfully !'));		
				
			   }
			   
			   return $message;
			   
			   
    }
	
	
	
	
	public function  sendEmail($url,$server_message,$params){
		
	if(Configuration::get('RECEIVE_EMAIL_NOTIFICATION',null, null, $this->context->shop->id)==1 && Configuration::get('EMAIL_ADRESS',null, null, $this->context->shop->id)!='')
	{		
	      $email=Configuration::get('EMAIL_ADRESS',null, null, $this->context->shop->id);	
	   	  $to=$email;
             
          $message_title =$this->l('Notification about new Order');
		      /* Getting differents vars*/
		
		$order = $params['order'];
		
		/* $order_state = $params['orderStatus'];  ndiaga */
	   $nka_current_state=$order->current_state;
	   $order_state =new OrderState((int)$nka_current_state);	
	   
        $context = Context::getContext();
        $id_lang = (int) $context->language->id;
        $id_shop = (int) $context->shop->id;
        $currency = $this->context->currency;        
        $customer = $this->context->customer;
        $configuration = Configuration::getMultiple(
            array(
                'PS_SHOP_EMAIL',
                'PS_MAIL_METHOD',
                'PS_MAIL_SERVER',
                'PS_MAIL_USER',
                'PS_MAIL_PASSWD',
                'PS_SHOP_NAME',
                'PS_MAIL_COLOR',
            ), $id_lang, null, $id_shop
        );
        $delivery = new Address((int) $order->id_address_delivery);
        $invoice = new Address((int) $order->id_address_invoice);
        $order_date_text = Tools::displayDate($order->date_add);
        $carrier = new Carrier((int) $order->id_carrier);
        $message = $this->getAllMessages($order->id);

        if (!$message || empty($message)) {
            $message = $this->trans('No message', array(), 'Modules.Mailalerts.Admin');
        }

        $items_table = '';

        $products = $params['order']->getProducts();
        $customized_datas = Product::getAllCustomizedDatas((int) $params['cart']->id);
        Product::addCustomizationPrice($products, $customized_datas);
        foreach ($products as $key => $product) {
            $unit_price = Product::getTaxCalculationMethod($customer->id) == PS_TAX_EXC ? $product['product_price'] : $product['product_price_wt'];

            $customization_text = '';
            if (isset($customized_datas[$product['product_id']][$product['product_attribute_id']])) {
                foreach ($customized_datas[$product['product_id']][$product['product_attribute_id']][$order->id_address_delivery] as $customization) {
                    if (isset($customization['datas'][Product::CUSTOMIZE_TEXTFIELD])) {
                        foreach ($customization['datas'][Product::CUSTOMIZE_TEXTFIELD] as $text) {
                            $customization_text .= $text['name'].': '.$text['value'].'<br />';
                        }
                    }

                    if (isset($customization['datas'][Product::CUSTOMIZE_FILE])) {
                        $customization_text .= count($customization['datas'][Product::CUSTOMIZE_FILE]).' '.$this->trans('image(s)', array(), 'Modules.Mailalerts.Admin').'<br />';
                    }

                    $customization_text .= '---<br />';
                }
                if (method_exists('Tools', 'rtrimString')) {
                    $customization_text = Tools::rtrimString($customization_text, '---<br />');
                } else {
                    $customization_text = preg_replace('/---<br \/>$/', '', $customization_text);
                }
            }

            $url = $context->link->getProductLink($product['product_id']);
            $items_table .=
                '<tr style="background-color:'.($key % 2 ? '#DDE2E6' : '#EBECEE').';">
					<td style="padding:0.6em 0.4em;">'.$product['product_reference'].'</td>
					<td style="padding:0.6em 0.4em;">
						<strong><a href="'.$url.'">'.$product['product_name'].'</a>'
                            .(isset($product['attributes_small']) ? ' '.$product['attributes_small'] : '')
                            .(!empty($customization_text) ? '<br />'.$customization_text : '')
                        .'</strong>
					</td>
					<td style="padding:0.6em 0.4em; text-align:right;">'.Tools::displayPrice($unit_price, $currency, false).'</td>
					<td style="padding:0.6em 0.4em; text-align:center;">'.(int) $product['product_quantity'].'</td>
					<td style="padding:0.6em 0.4em; text-align:right;">'
                        .Tools::displayPrice(($unit_price * $product['product_quantity']), $currency, false)
                    .'</td>
				</tr>';
        }
        foreach ($params['order']->getCartRules() as $discount) {
            $items_table .=
                '<tr style="background-color:#EBECEE;">
						<td colspan="4" style="padding:0.6em 0.4em; text-align:right;">'.$this->trans('Voucher code:', array(), 'Modules.Mailalerts.Admin').' '.$discount['name'].'</td>
					<td style="padding:0.6em 0.4em; text-align:right;">-'.Tools::displayPrice($discount['value'], $currency, false).'</td>
			</tr>';
        }
        if ($delivery->id_state) {
            $delivery_state = new State((int) $delivery->id_state);
        }
        if ($invoice->id_state) {
            $invoice_state = new State((int) $invoice->id_state);
        }

        if (Product::getTaxCalculationMethod($customer->id) == PS_TAX_EXC) {
            $total_products = $order->getTotalProductsWithoutTaxes();
        } else {
            $total_products = $order->getTotalProductsWithTaxes();
        }		
	  
		
		  $message_title =$this->l('Notification about new Order');
          $message_subject =$this->l('Hi, new order was sent to the cash  system.'); 
          $notif_det_text=$this->l('Notification details');
		  $notif_det_date=$this->l('Sent on:');
         		  
          $date = date('d/m/y');
		  $base_dir_nka=Tools::getHttpHost(true).__PS_BASE_URI__;   
			        
		  
		   $html='';	  
           $html.=$server_message; 
           $html.='<br/> URL: '.$url; 		
		
		  
		  
		  
          return  Mail::Send(
                  $this->context->language->id,
                  //'ostatusnotice_conf',
				  'new_order',
                  Mail::l($message_title, $this->context->language->id),
			array(	  
              '{html}' => $html,                        
             '{date}' => $date, 
			'{base_dir_nka}'=>$base_dir_nka,						
            '{message_title}'=>$message_title, 		
            '{message_subject}'=>$message_subject, 
            '{username}'=>'', 	
            '{phone}'=>'', 
			'{notif_det_text}'=>$notif_det_text,
            '{notif_det_date}'=>$notif_det_date,						
            '{firstname}' => $customer->firstname,
            '{lastname}' => $customer->lastname,
            '{email}' => $customer->email,
			'{delivery_block_txt}' => ConfigHistory::getFormatedAddress($delivery, "\n"),
            '{invoice_block_txt}' => ConfigHistory::getFormatedAddress($invoice, "\n"),
            '{delivery_block_html}' => ConfigHistory::getFormatedAddress(
                $delivery, '<br />', array(
                    'firstname' => '<span style="color:'.$configuration['PS_MAIL_COLOR'].'; font-weight:bold;">%s</span>',
                    'lastname' => '<span style="color:'.$configuration['PS_MAIL_COLOR'].'; font-weight:bold;">%s</span>',
                )
            ),
            '{invoice_block_html}' => ConfigHistory::getFormatedAddress(
                $invoice, '<br />', array(
                    'firstname' => '<span style="color:'.$configuration['PS_MAIL_COLOR'].'; font-weight:bold;">%s</span>',
                    'lastname' => '<span style="color:'.$configuration['PS_MAIL_COLOR'].'; font-weight:bold;">%s</span>',
                )
            ),
			'{delivery_company}' => $delivery->company,
            '{delivery_firstname}' => $delivery->firstname,
            '{delivery_lastname}' => $delivery->lastname,
            '{delivery_address1}' => $delivery->address1,
            '{delivery_address2}' => $delivery->address2,
            '{delivery_city}' => $delivery->city,
            '{delivery_postal_code}' => $delivery->postcode,
            '{delivery_country}' => $delivery->country,
            '{delivery_state}' => $delivery->id_state ? $delivery_state->name : '',
            '{delivery_phone}' => $delivery->phone ? $delivery->phone : $delivery->phone_mobile,
            '{delivery_other}' => $delivery->other,			
			'{invoice_company}' => $invoice->company,
            '{invoice_firstname}' => $invoice->firstname,
            '{invoice_lastname}' => $invoice->lastname,
            '{invoice_address2}' => $invoice->address2,
            '{invoice_address1}' => $invoice->address1,
            '{invoice_city}' => $invoice->city,
            '{invoice_postal_code}' => $invoice->postcode,
            '{invoice_country}' => $invoice->country,
            '{invoice_state}' => $invoice->id_state ? $invoice_state->name : '',
            '{invoice_phone}' => $invoice->phone ? $invoice->phone : $invoice->phone_mobile,
            '{invoice_other}' => $invoice->other,
			'{order_name}' => $order->reference,
            '{order_status}' => $order_state->name[$this->context->language->id],
            '{shop_name}' => $configuration['PS_SHOP_NAME'],
            '{date}' => $order_date_text,
            '{carrier}' => (($carrier->name == '0') ? $configuration['PS_SHOP_NAME'] : $carrier->name),
            '{payment}' => Tools::substr($order->payment, 0, 32),
            '{items}' => $items_table,			
			'{total_paid}' => Tools::displayPrice($order->total_paid, $currency),
            '{total_products}' => Tools::displayPrice($total_products, $currency),
            '{total_discounts}' => Tools::displayPrice($order->total_discounts, $currency),
            '{total_shipping}' => Tools::displayPrice($order->total_shipping, $currency),
            '{total_tax_paid}' => Tools::displayPrice(
                ($order->total_products_wt - $order->total_products) + ($order->total_shipping_tax_incl - $order->total_shipping_tax_excl),
                $currency,
                false
            ),
            '{total_wrapping}' => Tools::displayPrice($order->total_wrapping, $currency),
            '{currency}' => $currency->sign,
            '{gift}' => (bool) $order->gift,
            '{gift_message}' => $order->gift_message,
            '{message}' => $message,
			
			),
                  pSQL($to),
                  null,
                  null ,
                  null,
                  null,
                  null,
                  dirname(__FILE__).'/mails/',
                  false,
                  $this->context->shop->id
              );
			
			
			
	}		
		
	}
	
	
	
	/*
     *  From ps_emailalert  module
     */	
	 public function getAllMessages($id)
    {
        $messages = Db::getInstance()->executeS('
			SELECT `message`
			FROM `'._DB_PREFIX_.'message`
			WHERE `id_order` = '.(int) $id.'
			ORDER BY `id_message` ASC');
        $result = array();
        foreach ($messages as $message) {
            $result[] = $message['message'];
        }

        return implode('<br/>', $result);
    }
	
	
	
	public function getPaymentMethods(){
		
		$payment_methods = array();
        foreach (PaymentModule::getInstalledPaymentModules() as $payment) {
            $module = Module::getInstanceByName($payment['name']);
            if (Validate::isLoadedObject($module) && $module->active) {
                $payment_methods[$module->id] = $module->displayName;
				
            }
        }
		
		return $payment_methods; 
		
	}
	
	/*  adding  new Carrier Match */
	
	public  function addNewMatches($id_carrier,$livraison_id){
		
		$message='';
		
		if(Tools::isSubmit('submitCarrierMatches')){ 
		
		$CarrierMatches=new CarrierMatches();
		$CarrierMatches->id_carrier=$id_carrier;
		$CarrierMatches->livraison_id=$livraison_id;
		$CarrierMatches->id_shop =(int)Tools::getValue('id_shop');  
		
		$CarrierMatches->add();
		
		$message=$this->displayConfirmation($this->l('Carrier Added Successfully ! '));
		
		}
		
		
		return $message;
		
	}
	
	
	public  function addNewPaymentMatches($id_payment,$cash_payment_id){
		
		$message='';
		
		if(Tools::isSubmit('submitPaymentMatches')){ 
		
		$PaymentMatches=new PaymentMatches();
		$PaymentMatches->id_payment=$id_payment;
		$PaymentMatches->cash_payment_id=$cash_payment_id;
		$PaymentMatches->id_shop =(int)Tools::getValue('id_shop'); 
		
		$PaymentMatches->add();
		
		$message=$this->displayConfirmation($this->l('Payment  Added Successfully ! '));
		
		}
		
		
		return $message;
		
	}
	
	
	
	/*  new  code  for  email  and  WhatsApp*/	
	
	 
	
	
	
	
}

?>
